@@ -11,7 +11,7 @@ use Moo;
 use IPC::Run3; # For run3().
 use Types::Standard qw/Any ArrayRef HasMethods HashRef Int Str/;
 
-our $VERSION = '2.55';
+our $VERSION = '2.56';
 
 my $DATA_SECTION = get_data_section; # load once
 
@@ -183,7 +183,7 @@ sub BUILD
 	my($global)  =
 	{
 		directed		=> $$globals{directed} ? 'digraph' : 'graph',
-		driver			=> $$globals{driver} || which('dot'),
+		driver			=> $$globals{driver} || scalar(which('dot')),
 		format			=> $$globals{format} ||	'svg',
 		im_format		=> $$globals{im_format} || 'cmapx',
 		label			=> $$globals{directed} ? '->' : '--',
